//======================================================================================
//  TDdecodece.h : definition of the image engine SDK API functions
//  Copyright (C) 2003 CASIO COMPUTER CO., LTD.
//======================================================================================
// $RCSfile: TDdecodece.h $
// $Revision: 1.00 $
// $Date: 2003/02/21 $
// $Author: Toru Kitagawa $

#ifndef _DECODE_CE

    #define _DECODE_CE

    //-----------------------------------------------------------------------------
    //	These are the possible return values for all API functions
    //	They indicate either success, or the type of error encountered.
    //-----------------------------------------------------------------------------
    typedef enum
    {
        RESULT_INITIALIZE = -1,
        RESULT_SUCCESS  = 0,            // Operation was successful
	    RESULT_ERR_BADFILENAME,
    	RESULT_ERR_BADPORT,
    	RESULT_ERR_BADREGION,
	    RESULT_ERR_DRIVER,				//	Error occurred communicating with engine driver
    	RESULT_ERR_ENGINEBUSY,
	    RESULT_ERR_FILE,
    	RESULT_ERR_FILEINCOMPATIBLE,
	    RESULT_ERR_FILEINVALID,
    	RESULT_ERR_MEMORY,
	    RESULT_ERR_NODECODE,
    	RESULT_ERR_NODRIVER,
	    RESULT_ERR_NOIMAGE,
    	RESULT_ERR_NORESPONSE,
	    RESULT_ERR_NOTCONNECTED,
    	RESULT_ERR_PARAMETER,			// One of the function parameters was invalid
	    RESULT_ERR_UNSUPPORTED,			// The operation was not supported by the engine
    	RESULT_ERR_UPGRADE,
	    RESULT_ERR_MENUDECODE,
    	RESULT_ERR_REFLASH,
        RESULT_ERR_NOTRIGGER,           // "trigger" monitored during oemWaitForDecode has been "released"
    	RESULT_ERR_BADSMARTIMAGE,
	    RESULT_ERR_SMARTIMAGETOOLARGE,
        RESULT_ERR_BUFFER_TOO_SMALL,
        RESULT_ERR_NONEWDECODE          // decoding result overlaps in the one in front

    } Result_t;

    //-----------------------------------------------------------------------------
    //	Supported OCR Fonts
    //-----------------------------------------------------------------------------
    typedef enum
    {
    	OCR_DISABLED = 0,
    	OCR_A,
	    OCR_B,
    	OCR_MONEY,
        OCR_MICR_UNSUPPORTED,

    } OCRMode_t;

    //-----------------------------------------------------------------------------
    // OCR directions
    //-----------------------------------------------------------------------------
    typedef enum
    {
	    LeftToRight = 0,
    	TopToBottom,
	    RightToLeft,
    	BottomToTop,

    } OCRDirection_t;

    //-----------------------------------------------------------------------------
    // Image formats
    //-----------------------------------------------------------------------------
    typedef enum
    {
    	FF_RAW_BINARY = 0,
	    FF_RAW_GRAY,

    } FileFormat_t;

    //-----------------------------------------------------------------------------
    // Setup type
    //-----------------------------------------------------------------------------
    typedef enum
    {
	    SETUP_TYPE_DEFAULT = 0,
    	SETUP_TYPE_CURRENT,

    } SetupType_t;

    //-----------------------------------------------------------------------------
    // Illumination mode during scan.
    //-----------------------------------------------------------------------------
    typedef enum
    {
        SCAN_ILLUM_AIMER_OFF=0,             // Neither aimers or illumination
        SCAN_ILLUM_ONLY_ON,                 // Illumination only
        SCAN_AIMER_ONLY_ON,                 // Aimers only
        SCAN_ILLUM_AIMER_ON                 // Both aimers and illumination.
	
    } ScanIlluminat_t;
	
	
	//-----------------------------------------------------------------------------
	// Exposure Mode type
	//-----------------------------------------------------------------------------
	typedef enum {
		EXP_MODE_FIXED,
		EXP_MODE_ONCHIP,
		EXP_MODE_CASIO
	}ExposureMode_t;

    //------------------------------------------------------------------
    //	Structs
    //------------------------------------------------------------------

	//----------------------------------------------------------------------------------
	// Data structure that defines all possible imager settings used by the imager
	// during image acquisition
	//----------------------------------------------------------------------------------
	typedef struct
	{
		int				Exposure;           //
		int				MaxExposure;		//
		int				Gain;				//
		int				MaxGain;			//
		int				TargetWhite;        // Acceptable target white value falls within the
		int				TargetWhiteWindow;  // range TargetWhite +/- TargetWhiteWindow
		int				ImageMustConform;	// Image must conform to defined exposure parameters
		int				NumUpdates;         // Max number of attempts to achieve target white value
		int				FrameRate;			//
		int				SpecExclusion;		//
		int				SpecSaturation;		//
		int				SpecLimit;			//
		int				FixedExposure;		// Exposure setting for fixed exposure mode
		int				FixedGain;			// Gain setting for fixed exposure mode
		int				FixedFrameRate;		// Frame rate for fixed exposure mode
	} ExposureSettings_t;


	typedef struct
    {
	    int		NumUpdates;			// limit number of attempts to target white value
    	int		Exposure;			// max exposure setting for imager
	    int		Gain;
    	int		TargetWhite;		// acceptable target white value falls within the
        int     TargetWhiteWindow;  // range TargetWhite +/- TargetWhiteWindow
    	int		Reserved;			// must be set to -1

    } ImagerSetup_t;

    //------------------------------------------------------------------
    //  Data structure that sets up the format of images the engine returns
    //------------------------------------------------------------------
    typedef struct
    {
        int             left;       // left margin of image
    	int				right;		// right margin of image
        int             top;        // top margin of image
    	int				bottom;		// bottom margin of image
	    int				PixelSkip;
    	BOOL            Invert;		// Flag for flipping the image
    	FileFormat_t	format;		// format of image

    } ImageDesc_t;

    //------------------------------------------------------------------
    //  Data structure that sets up intelligent imaging settings
    //------------------------------------------------------------------
    typedef struct
    {
    	int				AspectRatio;	// ratioof barcode height to narrow elem width
	    int				OffsetX;		// offset in X direction, relative to barcode center
    	int				OffsetY;		// offset in Y direction
	    unsigned int	width;			// width of image in IntellBarcodeUnits
    	unsigned int	height;			// height of image
	    int				resolution;		// # pixels/IntellBarcodeUnits
    	FileFormat_t	format;
	    int				reserved;		// must be set to -1

    } IntellImgDesc_t;

    //------------------------------------------------------------------
    //	Data structure that holds the decoded barcode message.
    //------------------------------------------------------------------
    typedef struct
    {
    	TCHAR*		pchMessage;			// decoded message data
    	TCHAR		chCodeID;
	    TCHAR		chSymLetter;
    	TCHAR		chSymModifier;
        WORD        nLength;			// length of the decoded message

    } DecodeMsg_t;



    //-----------------------------------------------------------------------------
    //	AIM Symbology ID characters
    //-----------------------------------------------------------------------------
    #define	AIMID_AZTEC			'z'
    #define	AIMID_MESA			'z'
    #define	AIMID_CODABAR		'F'
    #define	AIMID_CODE11		'H'
    #define	AIMID_CODE128		'C'
    #define	AIMID_CODE39		'A'
    #define	AIMID_CODE49		'T'
    #define	AIMID_CODE93		'G'
    #define	AIMID_COMPOSITE		'e'
    #define	AIMID_DATAMATRIX	'd'
    #define	AIMID_EAN			'E'
    #define	AIMID_INT25			'I'
    #define	AIMID_MAXICODE		'U'
    #define	AIMID_MICROPDF		'L'
    #define	AIMID_PDF417		'L'
    #define	AIMID_OCR			'o'
    #define	AIMID_QR			'Q'
    #define	AIMID_RSS			'e'
    #define	AIMID_UPC			'E'
    #define	AIMID_POSTNET		'X'
    #define	AIMID_ISBT			'C'
    #define	AIMID_BPO			'X'
    #define	AIMID_CANPOST		'X'
    #define	AIMID_AUSPOST		'X'
    #define	AIMID_IATA25		'R'
    #define	AIMID_CODABLOCK		'O'
    #define	AIMID_JAPOST		'X'
    #define	AIMID_PLANET		'X'
    #define	AIMID_DUTCHPOST		'X'
    #define	AIMID_MSI			'M'
    #define AIMID_TLC39			'L'

    //-----------------------------------------------------------------------------
    //	Welch Allyn Symbology ID characters
    //-----------------------------------------------------------------------------
    #define	SYMID_AZTEC			'z'
    #define	SYMID_MESA			'Z'
    #define	SYMID_CODABAR		'a'
    #define	SYMID_CODE11		'h'
    #define	SYMID_CODE128		'j'
    #define	SYMID_CODE39		'b'
    #define	SYMID_CODE49		'l'
    #define	SYMID_CODE93		'i'
    #define	SYMID_COMPOSITE		'y'
    #define SYMID_DATAMATRIX    'w'
    #define	SYMID_EAN			'd'
    #define	SYMID_INT25			'e'
    #define	SYMID_MAXICODE		'x'
    #define	SYMID_MICROPDF		'R'
    #define	SYMID_PDF417		'r'
    #define	SYMID_POSTNET		'P'
    #define	SYMID_OCR			'O'
    #define	SYMID_QR			's'
    #define	SYMID_RSS			'y'
    #define	SYMID_UPC			'c'
    #define	SYMID_ISBT			'j'
    #define	SYMID_BPO			'B'
    #define	SYMID_CANPOST		'C'
    #define	SYMID_AUSPOST		'A'
    #define	SYMID_IATA25		'f'
    #define	SYMID_CODABLOCK		'q'
    #define	SYMID_JAPOST		'J'
    #define	SYMID_PLANET		'L'
    #define	SYMID_DUTCHPOST		'K'
    #define	SYMID_MSI			'g'
    #define SYMID_TLC39			'T'

    //-----------------------------------------------------------------------------
    // Symbology selection constants
    //-----------------------------------------------------------------------------
    enum
    {
        SYM_AZTEC = 0,
        SYM_MESA,
        SYM_CODABAR,
        SYM_CODE11,
        SYM_CODE128,
        SYM_CODE39,
        SYM_CODE49,
        SYM_CODE93,
        SYM_COMPOSITE,
        SYM_DATAMATRIX,
        SYM_EAN8,
        SYM_EAN13,
        SYM_INT25,
        SYM_MAXICODE,
        SYM_MICROPDF,
        SYM_OCR,
        SYM_PDF417,
        SYM_POSTNET,
        SYM_QR,
        SYM_RSS,
        SYM_UPCA,
        SYM_UPCE0,
        SYM_UPCE1,
        SYM_ISBT,
        SYM_BPO,
        SYM_CANPOST,
        SYM_AUSPOST,
        SYM_IATA25,
        SYM_CODABLOCK,
        SYM_JAPOST,
        SYM_PLANET,
        SYM_DUTCHPOST,
        SYM_MSI,
        SYM_TLCODE39,
        NUM_SYMBOLOGIES
    };

    //-----------------------------------------------------------------------------
    //	Handy constants used by API and users of the API
    //-----------------------------------------------------------------------------
    #define	ENGINE_API_RESPONSE_LEN		    1000
    #define MAX_SEND_BYTES                  256
    #define	MAX_VOLUME                      5
    #define	MIN_VOLUME                      0
    #define	MAX_SYMBOLOGIES                 100
    #define	MAX_IMAGE_SIZE					500000
    #define	SIZEOF_RGBQUAD					4

    // Centering Box Min/Max
    #define	DECODE_WINDOW_ULX_MIN           0
    #define	DECODE_WINDOW_ULX_MAX           319
    #define	DECODE_WINDOW_ULY_MIN           0
    #define	DECODE_WINDOW_ULY_MAX           239
    #define	DECODE_WINDOW_LRX_MIN           320
    #define	DECODE_WINDOW_LRX_MAX           639
    #define	DECODE_WINDOW_LRY_MIN           240
    #define	DECODE_WINDOW_LRY_MAX           479
    // Centering Box defaults
    #define	DEFAULT_DECODE_WINDOW_ULX       290
    #define	DEFAULT_DECODE_WINDOW_ULY       210
    #define	DEFAULT_DECODE_WINDOW_LRX       350
    #define	DEFAULT_DECODE_WINDOW_LRY       270

	#define HHP_DEC_ONLY 0
	#define EXT_DEC_ONLY 1
	#define EXT_AND_HHP 2

    enum
    {
	    INTEL_IMG_MOVE_LEFT = 0,
    	INTEL_IMG_MOVE_RIGHT,
	    INTEL_IMG_MOVE_UP,
    	INTEL_IMG_MOVE_DOWN,
	    INTEL_IMG_BAD_CODEID,
    	INTEL_IMG_ONE_SIDED_PDF,
	    INTEL_IMG_OUT_OF_RANGE,
    	INTEL_IMG_IS_NULL,
	    INTEL_IMG_EVERYTHING_OK
    };
	
    //-----------------------------------------------------------------------------
    //	Save Image File Format
    //-----------------------------------------------------------------------------
    
    #define IMG_FORMAT_BMP          0
	#define IMG_FORMAT_JPEG_LOW     1
	#define IMG_FORMAT_JPEG_MID     2
	#define IMG_FORMAT_JPEG_HI      3
	
	#define IMG_FORMAT_PROG_STRETCH 0x00000100
	#define IMG_FORMAT_PROG_BINARY  0x00000200
	
    //-----------------------------------------------------------------------------
    //	TDWaitForDecode
    //-----------------------------------------------------------------------------
    
    #define DECODEMODE_NORMAL       0
    #define DECODEMODE_MULTISTEP    1
    #define DECODEMODE_PACKAGE      2
    
    #define TD_BUZZER_OFF           0
    #define TD_BUZZER_ON            1
    
    #define TD_LED_OFF              0
    #define TD_LED_ON               1
    
#ifdef __cplusplus
extern "C"
{
#endif

/*
******************************************************************************
*
*                  Error Code/Message Functions
*
******************************************************************************
*/
    Result_t TDGetErrorMessage( PTCHAR ptcErrorMsg,Result_t nError );
/*
******************************************************************************
*
*                Scanner Connect/Disconnect/Version
*
******************************************************************************
*/
    Result_t TDConnect( void );
    Result_t TDDisconnect( void );
    Result_t TDGetAPIRevision( PTCHAR ptcRev );
/*
******************************************************************************
*
*                        Hardware Control Functions
*
******************************************************************************
*/
    Result_t TDAimerOn( BOOL bEnable );
    Result_t TDLightsOn( BOOL bEnable );
/*
******************************************************************************
*
*                          Imaging Functions
*
******************************************************************************
*/
    Result_t TDAcquireImage( const ImagerSetup_t* pImagerSetup );
    Result_t TDGetImage( PBYTE pImageBuffer,PDWORD pdwSize,WORD nTop,WORD nLeft,WORD nRight,WORD nBottom,
                                          WORD nSkip,WORD nBits,FileFormat_t nFormat,WORD nWhiteValue,WORD nExposeAttempts,
                                          WORD nGap,BOOL Invert,void (* fpProgress)(WORD) );
    Result_t TDGetImageData( DWORD wNumberToRead,PBYTE pBuffer,PDWORD pNumBytesRead );
    Result_t TDGetImagerInfo( PWORD pnCols,PWORD pnRows,PWORD pnBits );
    Result_t TDGetLastImageSize( PWORD pnCols,PWORD pnRows,PDWORD pdwSize );
    Result_t TDImageStreamInit( WORD nSkip,RECT *imgRect,BOOL bFlip );
    Result_t TDImageStreamStart( void );
    Result_t TDImageStreamRead( PBYTE pImageBuffer,PDWORD pdwSize );
    Result_t TDImageStreamStop( void );
    Result_t TDStartIntellImgXfer( const IntellImgDesc_t* pImageDesc );
    Result_t TDGetSetupImager( SetupType_t SetupType,ImagerSetup_t* pImagerSetup );
/*
******************************************************************************
*
*                       Barcode Capture Functions
*
******************************************************************************
*/
    Result_t TDGetDecodeCenteringWindow( SetupType_t SetupType,PBOOL pbEnabled,PRECT pIntersectRect );
    Result_t TDGetMaxMessageChars( PWORD pnChars );
    Result_t TDGetMessage( PTCHAR ptcMessage,PTCHAR ptcCodeID,PTCHAR ptcAIMID,PTCHAR ptcSymModifier,PWORD pnLength );
    Result_t TDGetPrintWeight( SetupType_t SetupType,PWORD pnPrintWeight );
    Result_t TDSetDecodeCenteringWindow( BOOL bEnable,PRECT pIntersectRect );
    Result_t TDSetPrintWeight( WORD nPrintWeight );
    Result_t TDWaitForDecode( DWORD dwTime,PTCHAR ptcMessage,PTCHAR ptcCodeID,PTCHAR ptcAimId,
                                               PTCHAR ptcSymModifier,PWORD pnLength,BOOL (*fpCallBack)(void) );
    Result_t TDGetDecodeMode( WORD *wMode, WORD *wNum, TCHAR *tcSeparator );
    Result_t TDSetDecodeMode( WORD wMode, WORD wNum, TCHAR tcSeparator );
    Result_t TDGetIndicator( WORD *pwLED, WORD *pwBuzzer );
    Result_t TDSetIndicator( WORD wLED, WORD wBuzzer );

/*
******************************************************************************
*
*                   Symbology Enable/Disable Functions
*
******************************************************************************
*/
    Result_t TDDefaultSymbology( PBOOL pSymbology );
    Result_t TDDisableSymbology( PBOOL pSymbology );
    Result_t TDEnableSymbology( PBOOL pSymbology );
    Result_t TDEnableSymbologyAll( void );
    Result_t TDDisableSymbologyAll( void );
/*
******************************************************************************
*
*                  Symbology Get Config Functions
*
******************************************************************************
*/
    Result_t TDGetSetupAll( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupAusPost( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupAztec( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupBPO( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupCanPost( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupCodabar( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,
                                                 PBOOL pbSSXmit,PBOOL pbCheckCharOn,PBOOL pbXmitCheckChar );
    Result_t TDGetSetupCodablock( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupCode11( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,
                                                PBOOL pbTwoCheckDigits );
    Result_t TDGetSetupCode128( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupCode39( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,PBOOL pbSSXmit,
                                                PBOOL pbFullAscii,PBOOL pbAppend,PBOOL pnCheckCharOn,PBOOL pbXmitCheckChar );
    Result_t TDGetSetupCode49( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupCode93( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupComposite( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupCompositeEx( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,
                                                     PBOOL pbCompositeOnUpcEan );
    Result_t TDGetSetupDataMatrix( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupDutchPost( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupEAN13( SetupType_t SetupType,PBOOL pbEnabled,PBOOL bXmitCheckChar,PBOOL pAddendaReq,
                           PBOOL bAddendaSeparator,PBOOL bAddenda2Digit,PBOOL bAddenda5Digit );
    Result_t TDGetSetupEAN8( SetupType_t SetupType,PBOOL pbEnabled,PBOOL bXmitCheckChar,PBOOL pAddendaReq,
                           PBOOL bAddendaSeparator,PBOOL bAddenda2Digit,PBOOL bAddenda5Digit );
    Result_t TDGetSetupIATA25( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupInt25( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,
                           PBOOL pbCheckDigitOn,PBOOL pbXmitCheckDigit );
    Result_t TDGetSetupISBT( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupJapost( SetupType_t SetupType,PBOOL pbEnabled );
    Result_t TDGetSetupMaxicode( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,
                                                  PBOOL pbCarrierMsgOnly );
    Result_t TDGetSetupMesa( SetupType_t SetupType,PBOOL pUMSEnabled,PBOOL pEMSEnabled,PBOOL p3MSEnabled,
                                              PBOOL p1MSEnabled,PBOOL pIMSEnabled,PBOOL p9MSEnabled );
    Result_t TDGetSetupMicroPDF( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupMSI( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength,PBOOL pbXmitCheckChar );
    Result_t TDGetSetupOCR( SetupType_t SetupType,OCRMode_t* pnFont,PTCHAR ptcTemplate,PTCHAR ptcGroupG,
                                             PTCHAR ptcGroupH,PTCHAR ptcCheckChar,OCRDirection_t* pnDirection );
    Result_t TDGetSetupPDF417( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupPlanet( SetupType_t SetupType,PBOOL pbEnabled,PBOOL pbXmitCheckDigit );
    Result_t TDGetSetupPostnet( SetupType_t SetupType,PBOOL pbEnabled,PBOOL pbXmitCheckDigit );
    Result_t TDGetSetupQR( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupRSS( SetupType_t SetupType,PBOOL pbEnabled,PWORD pbMinLength,PWORD pbMaxLength );
    Result_t TDGetSetupUPCA( SetupType_t SetupType,PBOOL pbEnabled,PBOOL pbXmitCheckDigit,PBOOL pbAddendaReq,
                                              PBOOL pbAddendaSeparator,PBOOL pbAddenda2Digit,PBOOL pbAddenda5Digit,PBOOL pbXmitNumSys );
    Result_t TDGetSetupUPCE( SetupType_t SetupType,PBOOL pbE0Enabled,PBOOL pbE1Enabled,PBOOL pbXmitCheckDigit,
                                              PBOOL pbAddendaReq,PBOOL pbExpandVersionE,PBOOL pbAddendaSeparator,PBOOL pbAddenda2Digit,
                                              PBOOL pbAddenda5Digit,PBOOL pbXmitNumSys );
/*
******************************************************************************
*
*                  Symbology Set Config Functions
*
******************************************************************************
*/
    Result_t TDSetupAztec( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCodabar( BOOL bSSXmit,BOOL bCheckCharOn,BOOL bXmitCheckChar,WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCodablock( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCode11( BOOL bTwoCheckDigits,WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCode128( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCode39( BOOL bSSXmit,BOOL bCheckCharOn,BOOL bXmitCheckChar,BOOL bFullAscii,
                                             BOOL bAppend,WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCode49( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCode93( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupComposite( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupCompositeEx( WORD nMinLength,WORD nMaxLength,BOOL bCompositeOnUpcEan );
    Result_t TDSetupDataMatrix( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupEAN13( BOOL bXmitCheckChar,BOOL bAddenda2Digit,BOOL bAddenda5Digit,BOOL bAddendaReq,BOOL bAddendaSeparator );
    Result_t TDSetupEAN8( BOOL bXmitCheckChar,BOOL bAddenda2Digit,BOOL bAddenda5Digit,BOOL bAddendaReq,BOOL bAddendaSeparator );
    Result_t TDSetupIATA25( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupInt25( BOOL bCheckDigitOn,BOOL bXmitCheckDigit,WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupMaxicode( BOOL bCarrierMsgOnly,WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupMesa( BOOL pUMSEnabled,BOOL pEMSEnabled,BOOL p3MSEnabled,BOOL p1MSEnabled,BOOL pIMSEnabled,BOOL p9MSEnabled );
    Result_t TDSetupMicroPDF( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupMSI( WORD nMinLength,WORD nMaxLength,BOOL bXmitCheckChar );
    Result_t TDSetupOCR( OCRMode_t nFont,PTCHAR ptcTemplate,PTCHAR ptcGroupG,PTCHAR ptcGroupH,PTCHAR ptcCheckChar,
                                          OCRDirection_t nDirection );
    Result_t TDSetupPDF417( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupPlanet( BOOL bXmitCheckDigit );
    Result_t TDSetupPostnet( BOOL bXmitCheckDigit );
    Result_t TDSetupQR( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupRSS( WORD nMinLength,WORD nMaxLength );
    Result_t TDSetupUPCA( BOOL bXmitCheckDigit,BOOL bXmitNumSys,BOOL bAddenda2Digit,BOOL bAddenda5Digit,BOOL bAddendaReq,
                                           BOOL bAddendaSeparator );
    Result_t TDSetupUPCE( BOOL bXmitCheckDigit,BOOL bXmitNumSys,BOOL bExpandVersionE,BOOL bAddenda2Digit,BOOL bAddenda5Digit,
                                           BOOL bAddendaReq,BOOL bAddendaSeparator );

/*
******************************************************************************
*
*                  Control LED illumination Strength
*
******************************************************************************
*/
    Result_t TDGetLEDIntensity(WORD *wAimLED, WORD *wIllumLED);
    Result_t TDSetLEDIntensity(WORD wAimLED, WORD wIllumLED);

/*
******************************************************************************
*
*                  Save Image File
*
******************************************************************************
*/
    Result_t TDMakeImageFile( TCHAR *pFileName, BYTE *pBuffer, DWORD dwSize, WORD nWidth, WORD nHeight, DWORD dwFormat);

/*
******************************************************************************
*
*                  Save Ini File & Load Ini File
*
******************************************************************************
*/
    Result_t TDSaveConfigFile( TCHAR *pFileName );
    Result_t TDLoadConfigFile( TCHAR *pFileName );

#ifdef __cplusplus
}
#endif

#endif
