// TDDemo : demonstration program of the scanner

#include <windows.h>
#include <commctrl.h>
#include "TDdecodece.h"
#include "ClbSys.h"
#include "resource.h"

#define MAX_LOADSTRING 100

// Global Variables:
HINSTANCE			hInst;			// The current instance
HWND				hwndCB;			// The command bar handle

// Forward declarations of functions included in this code module:
ATOM				MyRegisterClass	(HINSTANCE, LPTSTR);
BOOL				InitInstance	(HINSTANCE, int);
LRESULT CALLBACK	WndProc			(HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK	About			(HWND, UINT, WPARAM, LPARAM);

extern LRESULT CALLBACK DlgReadSymbol (HWND, UINT, WPARAM, LPARAM);
extern void PrintText(HWND hWnd, TCHAR *Text, int nLength, int *pos);
extern int ResetDisp(HWND hWnd);

extern void CaptureImage( HWND hWnd, BOOL bSave );
extern void SaveImage( HWND hWnd );
extern void ShowScanCode( HWND hWnd );
extern void CaptureShowSign( HWND hWnd );
extern DWORD ShowStreaming( HWND hWnd );

// global value
int g_iLine = 0;
int g_iMode = IDM_CAPTURE;
BOOL g_bStreaming = FALSE;

TCHAR mode_msg[6][32];
TCHAR szErrMessage[32];
TCHAR szErrConnect[64];
TCHAR szErrMemory[64];
extern TCHAR CodeList[NUM_SYMBOLOGIES][32];



// load string
void MyLoadString( HINSTANCE hInst )
{
	int i;
	// error message
	LoadString( hInst, ID_ERR_MESSAGE, szErrMessage,   32 );
	LoadString( hInst, ID_ERR_CONNECT, szErrConnect, 64 );
	LoadString( hInst, ID_ERR_MEMORY,  szErrMemory,  64 );
	// post code name
	LoadString( hInst, ID_SYM_BPO, CodeList[SYM_BPO], 32 );
	LoadString( hInst, ID_SYM_CANPOST, CodeList[SYM_CANPOST], 32 );
	LoadString( hInst, ID_SYM_AUSPOST, CodeList[SYM_AUSPOST], 32 );
	LoadString( hInst, ID_SYM_JAPPOST, CodeList[SYM_JAPOST], 32 );
	LoadString( hInst, ID_SYM_DUTPOST, CodeList[SYM_DUTCHPOST], 32 );
	// mode name
	for(i=0; i<5; i++){
		LoadString( hInst, ID_DEMO_MODE1+i, mode_msg[i], 32 );
	}
}
// show error message
void ShowErrorMessage(HWND hDlg, TCHAR *szErr)
{
	MessageBox(hDlg, szErr, szErrMessage, MB_OK | MB_ICONWARNING);
}

// register HotKey
void MyRegisterHotKey(HWND hWnd)
{
	RegisterHotKey(hWnd, ID_HOTKEY_L, 0, 0x87);
	RegisterHotKey(hWnd, ID_HOTKEY_R, MOD_KEYUP, 0x84);
}
// unregister HotKey
void MyUnregisterHotKey(HWND hWnd)
{
	UnregisterHotKey(hWnd, ID_HOTKEY_L);
	UnregisterHotKey(hWnd, ID_HOTKEY_R);
}

// double start-up checking
BOOL CheckExistingTDDemo(HINSTANCE hInstance)
{
	HWND hWnd;
	TCHAR szWindowClass[100], szTitle[100];
	
	LoadString(hInstance, IDC_TDDEMO, szWindowClass, MAX_LOADSTRING);
	LoadString(hInstance, IDS_APP_TITLE, szTitle, MAX_LOADSTRING);
	
	hWnd = FindWindow(szWindowClass, szTitle);
	
	if(hWnd != NULL) {
		SetForegroundWindow(hWnd);
		return TRUE;
	}
	return FALSE;
}

// main
int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	MSG msg;
	HACCEL hAccelTable;
	
	MyLoadString(hInstance);
	
	// double start-up prevention
	if( CheckExistingTDDemo(hInstance) ) {
		return FALSE;
	}
	
	// connect scanner
	if(TDConnect()!=RESULT_SUCCESS){
		ShowErrorMessage(HWND_DESKTOP, szErrConnect);
		return FALSE;
	}
	
	// Perform application initialization:
	if (!InitInstance (hInstance, nCmdShow)) 
	{
		return FALSE;
	}
	
	hAccelTable = LoadAccelerators(hInstance, (LPCTSTR)IDC_TDDEMO);
	
	// Main message loop:
	while (GetMessage(&msg, NULL, 0, 0)) 
	{
		if (!TranslateAccelerator(msg.hwnd, hAccelTable, &msg)) 
		{
			TranslateMessage(&msg);
			DispatchMessage(&msg);
		}
	}
	return msg.wParam;
}

//
//  FUNCTION: MyRegisterClass()
//
//  PURPOSE: Registers the window class.
//
//  COMMENTS:
//
//    It is important to call this function so that the application 
//    will get 'well formed' small icons associated with it.
//
ATOM MyRegisterClass(HINSTANCE hInstance, LPTSTR szWindowClass)
{
	WNDCLASS	wc;

    wc.style			= CS_HREDRAW | CS_VREDRAW;
    wc.lpfnWndProc		= (WNDPROC) WndProc;
    wc.cbClsExtra		= 0;
    wc.cbWndExtra		= 0;
    wc.hInstance		= hInstance;
    wc.hIcon			= LoadIcon(hInstance, MAKEINTRESOURCE(IDI_ICON1));
    wc.hCursor			= 0;
    wc.hbrBackground	= (HBRUSH) GetStockObject(WHITE_BRUSH);
    wc.lpszMenuName		= 0;
    wc.lpszClassName	= szWindowClass;

	return RegisterClass(&wc);
}

//
//  FUNCTION: InitInstance(HANDLE, int)
//
//  PURPOSE: Saves instance handle and creates main window
//
//  COMMENTS:
//
//    In this function, we save the instance handle in a global variable and
//    create and display the main program window.
//
BOOL InitInstance(HINSTANCE hInstance, int nCmdShow)
{
	HWND	hWnd;
	TCHAR	szTitle[MAX_LOADSTRING];			// The title bar text
	TCHAR	szWindowClass[MAX_LOADSTRING];		// The window class name

	hInst = hInstance;		// Store instance handle in our global variable
	// Initialize global strings
	LoadString(hInstance, IDC_TDDEMO, szWindowClass, MAX_LOADSTRING);
	MyRegisterClass(hInstance, szWindowClass);

	LoadString(hInstance, IDS_APP_TITLE, szTitle, MAX_LOADSTRING);
	hWnd = CreateWindow(szWindowClass, szTitle, WS_VISIBLE,
		CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, NULL, NULL, hInstance, NULL);

	if (!hWnd)
	{	
		return FALSE;
	}

	ShowWindow(hWnd, nCmdShow);
	UpdateWindow(hWnd);
	if (hwndCB)
		CommandBar_Show(hwndCB, TRUE);

	return TRUE;
}

//
//  FUNCTION: WndProc(HWND, unsigned, WORD, LONG)
//
//  PURPOSE:  Processes messages for the main window.
//
//  WM_COMMAND	- process the application menu
//  WM_PAINT	- Paint the main window
//  WM_DESTROY	- post a quit message and return
//
//
LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	int wmId, wmEvent;
	DWORD	tid;
	BOOL	ResPeek;
	MSG		msg;
	
	switch (message) {
		
		case WM_COMMAND:
			if( g_bStreaming ) break;
			
			wmId    = LOWORD(wParam); 
			wmEvent = HIWORD(wParam); 
			// Parse the menu selections:
			switch (wmId)
			{
				case IDM_CAPTURE:	// capture image
				case IDM_BITMAP:	// capture & save bitmap
				case IDM_STREAM:	// streaming
				case IDM_SIGN:      // sign capture
					g_iMode = wmId;
					g_iLine = ResetDisp( hWnd );
					PrintText( hWnd, mode_msg[g_iMode-IDM_CAPTURE],
						wcslen(mode_msg[g_iMode-IDM_CAPTURE]), &g_iLine );
					break;
				
				case IDM_READSYM:
					MyUnregisterHotKey( hWnd );
					DialogBox( hInst, (LPCTSTR)IDD_READSYM, hWnd, (DLGPROC)DlgReadSymbol );
					MyRegisterHotKey( hWnd );
					break;
				
				case IDM_HELP_ABOUT:
				   DialogBox( hInst, (LPCTSTR)IDD_ABOUTBOX, hWnd, (DLGPROC)About );
				   break;
				case IDM_FILE_EXIT:
				   SendMessage( hWnd, WM_DESTROY, 0, 0 );
				   break;
				default:
				   return DefWindowProc( hWnd, message, wParam, lParam );
			}
			break;
			
		case WM_HOTKEY:
			switch(wParam){
				case ID_HOTKEY_L:
					// capture image
					if (g_iMode == IDM_CAPTURE) {
						CLBPlayBuzzer( B_CLICK, 0, 0 );
						CaptureImage( hWnd, FALSE );
						break;
					} // capture & save bitmap
					else if(g_iMode == IDM_BITMAP) {
						CLBPlayBuzzer( B_CLICK, 0, 0 );
						CaptureImage( hWnd, TRUE );
						break;
					} // capture & show sign
					else if(g_iMode == IDM_SIGN) {
						CaptureShowSign( hWnd );
						break;
					} // capture & show streaming image
					else if(g_iMode == IDM_STREAM) {
						if( !g_bStreaming ) {
							CLBPlayBuzzer( B_CLICK, 0, 0 );
							CreateThread( NULL, 0,
								(LPTHREAD_START_ROUTINE)ShowStreaming, (void*)hWnd, 0, &tid );
						} else {
							CLBPlayBuzzer( B_CLICK, 0, 0 );
							g_bStreaming = FALSE;
						}
						break;
					}
					
					// clear key input
					do {
						ResPeek = PeekMessage( &msg , hWnd, WM_KEYFIRST, WM_KEYLAST, PM_REMOVE );
					} while (ResPeek == TRUE);
					
					break;// case ID_HOTKEY_L:
					
				case ID_HOTKEY_R:
					if(GetAsyncKeyState(0x84) < 0) TDAimerOn( TRUE );
					else                           TDAimerOn( FALSE );
					break;
			}// switch(wParam)
			break;
			
		case WM_CREATE:
			hwndCB = CommandBar_Create(hInst, hWnd, 1);
			CommandBar_InsertMenubar(hwndCB, hInst, IDM_MENU, 0);
			CommandBar_AddAdornments(hwndCB, 0, 0);
			// enable to read all symbologies
			TDEnableSymbologyAll();
			MyRegisterHotKey( hWnd );
			
			break;
		case WM_CLOSE:
		case WM_DESTROY:
			MyUnregisterHotKey( hWnd );
			TDDisconnect();
			CommandBar_Destroy(hwndCB);
			PostQuitMessage(0);
			break;
		default:
			return DefWindowProc(hWnd, message, wParam, lParam);
   }
   return 0;
}

// Mesage handler for the About box.
LRESULT CALLBACK About(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
{
	RECT rt, rt1;
	int DlgWidth, DlgHeight;	// dialog width and height in pixel units
	int NewPosX, NewPosY;

	switch (message)
	{
		case WM_INITDIALOG:
			// trying to center the About dialog
			if (GetWindowRect(hDlg, &rt1)) {
				GetClientRect(GetParent(hDlg), &rt);
				DlgWidth	= rt1.right - rt1.left;
				DlgHeight	= rt1.bottom - rt1.top ;
				NewPosX		= (rt.right - rt.left - DlgWidth)/2;
				NewPosY		= (rt.bottom - rt.top - DlgHeight)/2;
				
				// if the About box is larger than the physical screen 
				if (NewPosX < 0) NewPosX = 0;
				if (NewPosY < 0) NewPosY = 0;
				SetWindowPos(hDlg, 0, NewPosX, NewPosY,
					0, 0, SWP_NOZORDER | SWP_NOSIZE);
			}
			return TRUE;

		case WM_COMMAND:
			if ((LOWORD(wParam) == IDOK) || (LOWORD(wParam) == IDCANCEL))
			{
				EndDialog(hDlg, LOWORD(wParam));
				return TRUE;
			}
			break;
	}
    return FALSE;
}
